<div class="{{class}}">
    <div class="form-group">
        <label for="{{field.key}}">{{field.label}}</label>
        {% if field.disabled %}
        <input id="{{field.key}}" name="{{field.key}}" class="form-control" type="text" value="{{field.value}}" disabled/>
        {% else %}
        <select id="{{field.key}}" name="{{field.key}}" class="form-control" {% if tabindex %} tabindex="{{tabindex}}"{% endif %}>
            {% for value in field.values %}
            <option value="{{ value }}" {% if field.value == value %}selected{% endif %}>{{ value }}</option>
            {% endfor %}
        </select>
        {% endif %}
    </div>
</div>
