{% extends base %}

{% block content %}

<form method="post" id="form">
    {% csrf_token %}
    <input type="hidden" id="action" name="action"/>
    <input type="hidden" id="sort" name="sort" value="date_asc"/>
    <input type="hidden" name="path" value=":/django/columns"/>
    {% include "components/table.html" with table=table pagination=pagination %}
</form>

{% endblock %}
